==> python-keystoneauth1_5.6.0.orig.tar.gz: keystoneauth1-5.6.0/keystoneauth1/identity/v3/__init__.py <==
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

# flake8: noqa: F405

from keystoneauth1.identity.v3.application_credential import *  # noqa
from keystoneauth1.identity.v3.base import *  # noqa
from keystoneauth1.identity.v3.federation import *  # noqa
from keystoneauth1.identity.v3.k2k import *  # noqa
from keystoneauth1.identity.v3.multi_factor import *  # noqa
from keystoneauth1.identity.v3.oidc import *  # noqa
from keystoneauth1.identity.v3.password import *  # noqa
from keystoneauth1.identity.v3.receipt import *  # noqa
from keystoneauth1.identity.v3.token import *  # noqa
from keystoneauth1.identity.v3.totp import *  # noqa
from keystoneauth1.identity.v3.tokenless_auth import *  # noqa
from keystoneauth1.identity.v3.oauth2_client_credential import *  # noqa
from keystoneauth1.identity.v3.oauth2_mtls_client_credential import *  # noqa


__all__ = ('ApplicationCredential',
           'ApplicationCredentialMethod',

           'Auth',
           'AuthConstructor',
           'AuthMethod',
           'BaseAuth',

           'FederationBaseAuth',

           'Keystone2Keystone',

           'Password',
           'PasswordMethod',

           'Token',
           'TokenMethod',

           'OidcAccessToken',
           'OidcAuthorizationCode',
           'OidcClientCredentials',
           'OidcPassword',

           'TOTPMethod',
           'TOTP',

           'TokenlessAuth',

           'ReceiptMethod',

           'MultiFactor',

           'OAuth2ClientCredential',
           'OAuth2ClientCredentialMethod',

           'OAuth2mTlsClientCredential',
           )

==> python-keystoneauth1_5.12.0.orig.tar.gz: keystoneauth1-5.12.0/keystoneauth1/identity/v3/__init__.py <==
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

# flake8: noqa: F405

from keystoneauth1.identity.v3.application_credential import *  # noqa
from keystoneauth1.identity.v3.base import *  # noqa
from keystoneauth1.identity.v3.federation import *  # noqa
from keystoneauth1.identity.v3.k2k import *  # noqa
from keystoneauth1.identity.v3.multi_factor import *  # noqa
from keystoneauth1.identity.v3.oidc import *  # noqa
from keystoneauth1.identity.v3.password import *  # noqa
from keystoneauth1.identity.v3.receipt import *  # noqa
from keystoneauth1.identity.v3.token import *  # noqa
from keystoneauth1.identity.v3.totp import *  # noqa
from keystoneauth1.identity.v3.tokenless_auth import *  # noqa
from keystoneauth1.identity.v3.oauth2_client_credential import *  # noqa
from keystoneauth1.identity.v3.oauth2_mtls_client_credential import *  # noqa


__all__ = (
    'ApplicationCredential',
    'ApplicationCredentialMethod',
    'Auth',
    'AuthConstructor',
    'AuthMethod',
    'BaseAuth',
    'FederationBaseAuth',
    'Keystone2Keystone',
    'Password',
    'PasswordMethod',
    'Token',
    'TokenMethod',
    'OidcAccessToken',
    'OidcAuthorizationCode',
    'OidcClientCredentials',
    'OidcPassword',
    'TOTPMethod',
    'TOTP',
    'TokenlessAuth',
    'ReceiptMethod',
    'MultiFactor',
    'OAuth2ClientCredential',
    'OAuth2ClientCredentialMethod',
    'OAuth2mTlsClientCredential',
)
